@@ -1,14 +1,18 @@
-#' @name fasta
 #' @title Read and Write FASTA
 #' @description Read and write FASTA formatted files of sequences.
 #' 
 #' @param file a FASTA-formatted file of sequences.
-#' @param x a list or a matrix of DNA sequences (see \code{\link[ape]{write.dna}}).
+#' @param x a list or a matrix of DNA sequences (see \code{\link[ape]{write.dna}}), 
+#'   or a \code{\link{gtypes}} object with sequences.
 #' 
-#' @return for \code{read.fasta}, a set of sequences in DNAbin format.
+#' @return \describe{
+#'   \item{read.fasta}{a set of sequences in DNAbin format}
+#'   \item{write.fasta}{invisbly, name(s) of file(s) written}
+#' }
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
+#' @name fasta
 #' @aliases fasta
 #' @export
 #' 
@@ -24,6 +28,7 @@ read.fasta <- function(file) {
 #' @export
 #' 
 write.fasta <- function(x, file = "sequences.fasta") {
+  if(is.gtypes(x)) x <- sequences(x)
   fname <- if(inherits(x, "multidna")) {
     x <- getSequences(x, simplify = FALSE)
     sapply(names(x), function(gene) {
