@@ -1,4 +1,3 @@
-#' @name gtypes2loci
 #' @title Convert Between \code{gtypes} And \code{loci} objects.
 #' @description Convert a \code{gtypes} object to a \code{\link[pegas]{loci}} object.
 #' 
@@ -7,17 +6,28 @@
 #'  
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
-#' @seealso \link{initialize.gtypes}, \link{df2gtypes}, \link{sequence2gtypes}, 
-#'   \link{gtypes2df}, \link{gtypes2genind}
+#' @seealso \link{initialize.gtypes}, \link{df2gtypes}, 
+#'   \link{sequence2gtypes}, \link{as.data.frame.gtypes}, 
+#'   \link{gtypes2genind}
 #' 
+#' @examples
+#' data(msats.g)
+#' 
+#' # Convert to loci
+#' lc <- gtypes2loci(msats.g)
+#' lc
+#' 
+#' # Convert to gtypes
+#' gt <- loci2gtypes(lc)
+#' gt 
+#' 
+#' @name gtypes2loci 
 #' @importFrom pegas as.loci
 #' @export
 #' 
 gtypes2loci <- function(x) {
-  mat <- as.matrix(x, one.col = TRUE, sep = "/")
-  mat <- data.frame(cbind(as.character(strata(x)), mat))
-  mat <- data.frame(lapply(mat, factor))
-  as.loci(mat, col.pop = 1)
+  df <- as.data.frame(x, one.col = TRUE, sep = "/", ids = FALSE)
+  as.loci(df, col.pop = 1)
 }
 
 #' @rdname gtypes2loci
